summaryrefslogtreecommitdiffstats
path: root/server/src/com/vaadin/ui
diff options
context:
space:
mode:
Diffstat (limited to 'server/src/com/vaadin/ui')
-rw-r--r--server/src/com/vaadin/ui/AbstractComponent.java6
-rw-r--r--server/src/com/vaadin/ui/LoginForm.java4
-rw-r--r--server/src/com/vaadin/ui/UI.java35
3 files changed, 24 insertions, 21 deletions
diff --git a/server/src/com/vaadin/ui/AbstractComponent.java b/server/src/com/vaadin/ui/AbstractComponent.java
index c49d6237b8..57416e3a06 100644
--- a/server/src/com/vaadin/ui/AbstractComponent.java
+++ b/server/src/com/vaadin/ui/AbstractComponent.java
@@ -37,7 +37,7 @@ import com.vaadin.server.ComponentSizeValidator;
import com.vaadin.server.ErrorMessage;
import com.vaadin.server.Resource;
import com.vaadin.server.Terminal;
-import com.vaadin.server.VaadinSession;
+import com.vaadin.server.VaadinServiceSession;
import com.vaadin.shared.ComponentConstants;
import com.vaadin.shared.ComponentState;
import com.vaadin.shared.ui.ComponentStateUtil;
@@ -265,7 +265,7 @@ public abstract class AbstractComponent extends AbstractClientConnector
if (parent != null) {
return parent.getLocale();
}
- final VaadinSession session = getSession();
+ final VaadinServiceSession session = getSession();
if (session != null) {
return session.getLocale();
}
@@ -623,7 +623,7 @@ public abstract class AbstractComponent extends AbstractClientConnector
*/
protected void focus() {
if (this instanceof Focusable) {
- final VaadinSession session = getSession();
+ final VaadinServiceSession session = getSession();
if (session != null) {
getUI().setFocusedComponent((Focusable) this);
delayedFocus = false;
diff --git a/server/src/com/vaadin/ui/LoginForm.java b/server/src/com/vaadin/ui/LoginForm.java
index a748d8d4c5..76cec66f27 100644
--- a/server/src/com/vaadin/ui/LoginForm.java
+++ b/server/src/com/vaadin/ui/LoginForm.java
@@ -29,7 +29,7 @@ import com.vaadin.server.DownloadStream;
import com.vaadin.server.RequestHandler;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinResponse;
-import com.vaadin.server.VaadinSession;
+import com.vaadin.server.VaadinServiceSession;
import com.vaadin.shared.ApplicationConstants;
/**
@@ -87,7 +87,7 @@ public class LoginForm extends CustomComponent {
private final RequestHandler requestHandler = new RequestHandler() {
@Override
- public boolean handleRequest(VaadinSession session,
+ public boolean handleRequest(VaadinServiceSession session,
VaadinRequest request, VaadinResponse response)
throws IOException {
String requestPathInfo = request.getRequestPathInfo();
diff --git a/server/src/com/vaadin/ui/UI.java b/server/src/com/vaadin/ui/UI.java
index 0d9fcd2c0a..ba87eb1424 100644
--- a/server/src/com/vaadin/ui/UI.java
+++ b/server/src/com/vaadin/ui/UI.java
@@ -45,8 +45,8 @@ import com.vaadin.server.UIProvider;
import com.vaadin.server.VaadinRequest;
import com.vaadin.server.VaadinRequest.BrowserDetails;
import com.vaadin.server.VaadinService;
+import com.vaadin.server.VaadinServiceSession;
import com.vaadin.server.VaadinServlet;
-import com.vaadin.server.VaadinSession;
import com.vaadin.shared.EventId;
import com.vaadin.shared.MouseEventDetails;
import com.vaadin.shared.ui.BorderStyle;
@@ -69,9 +69,10 @@ import com.vaadin.util.ReflectTools;
* <p>
* When a new UI instance is needed, typically because the user opens a URL in a
* browser window which points to e.g. {@link VaadinServlet}, all
* {@link UIProvider}s registered to the current {@link VaadinSession} are
* queried for the UI class that should be used. The selection is by defaylt
* based on the {@value VaadinSession#UI_PARAMETER} parameter from web.xml.
* </p>
* <p>
* After a UI has been created by the application, it is initialized using
@@ -147,8 +148,9 @@ public abstract class UI extends AbstractComponentContainer implements
* The name also determines the URL that can be used for direct access
* to a window. All windows can be accessed through
* {@code http://host:port/app/win} where {@code http://host:port/app}
- * is the application URL (as returned by {@link VaadinSession#getURL()}
- * and {@code win} is the window name.
+ * is the application URL (as returned by
+ * {@link VaadinServiceSession#getURL()} and {@code win} is the window
+ * name.
* </p>
* <p>
* Note! Portlets do not support direct window access through URLs.
@@ -167,8 +169,9 @@ public abstract class UI extends AbstractComponentContainer implements
* The name also determines the URL that can be used for direct access
* to a window. All windows can be accessed through
* {@code http://host:port/app/win} where {@code http://host:port/app}
- * is the application URL (as returned by {@link VaadinSession#getURL()}
- * and {@code win} is the window name.
+ * is the application URL (as returned by
+ * {@link VaadinServiceSession#getURL()} and {@code win} is the window
+ * name.
* </p>
* <p>
* This method can only be called before the window is added to an
@@ -205,7 +208,7 @@ public abstract class UI extends AbstractComponentContainer implements
* to an application
*/
public URL getURL() {
- VaadinSession session = getSession();
+ VaadinServiceSession session = getSession();
if (session == null) {
return null;
}
@@ -450,7 +453,7 @@ public abstract class UI extends AbstractComponentContainer implements
/**
* The application to which this UI belongs
*/
- private VaadinSession session;
+ private VaadinServiceSession session;
/**
* List of windows in this UI.
@@ -468,7 +471,7 @@ public abstract class UI extends AbstractComponentContainer implements
* which a request originates. A negative value indicates that the UI id has
* not yet been assigned by the Application.
*
- * @see VaadinSession#getNextUIid()
+ * @see VaadinServiceSession#getNextUIid()
*/
private int uiId = -1;
@@ -600,8 +603,8 @@ public abstract class UI extends AbstractComponentContainer implements
* <p>
* Getting a null value is often a problem in constructors of regular
* components and in the initializers of custom composite components. A
- * standard workaround is to use {@link VaadinSession#getCurrent()} to
- * retrieve the application instance that the current request relates to.
+ * standard workaround is to use {@link VaadinServiceSession#getCurrent()}
+ * to retrieve the application instance that the current request relates to.
* Another way is to move the problematic initialization to
* {@link #attach()}, as described in the documentation of the method.
* </p>
@@ -610,7 +613,7 @@ public abstract class UI extends AbstractComponentContainer implements
* @see #attach()
*/
@Override
- public VaadinSession getSession() {
+ public VaadinServiceSession getSession() {
return session;
}
@@ -730,7 +733,7 @@ public abstract class UI extends AbstractComponentContainer implements
*
* @see #getSession()
*/
- public void setSession(VaadinSession session) {
+ public void setSession(VaadinServiceSession session) {
if ((session == null) == (this.session == null)) {
throw new IllegalStateException(
"VaadinSession has already been set");
@@ -1384,7 +1387,7 @@ public abstract class UI extends AbstractComponentContainer implements
* heartbeat for this UI.
*
* @see #heartbeat()
- * @see VaadinSession#cleanupInactiveUIs()
+ * @see VaadinServiceSession#cleanupInactiveUIs()
*
* @return The time the last heartbeat request occurred.
*/
@@ -69,9 +69,10 @@ import com.vaadin.util.ReflectTools;
* When a new UI instance is needed, typically because the user opens a URL in a
* browser window which points to e.g. {@link VaadinServlet}, all
- * {@link UIProvider}s registered to the current {@link VaadinSession} are
- * queried for the UI class that should be used. The selection is by defaylt
- * based on the {@value VaadinSession#UI_PARAMETER} parameter from web.xml.
+ * {@link UIProvider}s registered to the current {@link VaadinServiceSession}
+ * are queried for the UI class that should be used. The selection is by defaylt
+ * based on the {@value VaadinServiceSession#UI_PARAMETER} parameter from
+ * web.xml.
* </p>
* <p>